<?php

namespace WPPOOL\SCF;

if (!class_exists('\WPPOOL\SCF\App')) :
	final class App
	{


		// App options
		public static function options()
		{
			$options = array(
				'enabled'        => true,
				'whatsapp'       => array(
					'direct_web' => true,
					'phone_code'      => '44',
					'phone_number'    => '',
					'defined_preset'  => "Name: {name}{break}Email: {email} {break}Phone: {phone} {break}Message: {message}{break}",
					'preset'		  => ""
				),
				'icon'           => array(
					'delay'           => 0,
					'image'           => '',

					'size'            => 'medium',
					'size_custom'     => '',

					'position'        => 'right',
					'position_top'    => '',
					'position_left'   => '',
					'position_right'  => '',
					'position_bottom' => '',
				),
				'call_to_action' => array(
					'text'        => 'Contact us',

					'color'       => '#555555',
					'background'  => '#FFFFFF',

					'size'        => 'medium',
					'size_custom' => '',
				),
				'form'           => array(
					'title'          => 'Contact via WhatsApp',
					'header'          => '',
					'footer'          => '',
					'submit'          => 'Send on WhatsApp',

					'open_by_default' => false,
					'close_on_submit' => true,
					'open_in_new_tab' => true,

					'size'            => 'medium',
					'size_custom'     => '',

					'font'            => '',
					'color'           => '#ffffff',
					'background'      => '#09816D',
				),
			);

			return apply_filters('scf_options', $options);
		}

		// App fields
		public static function fields()
		{
			$fields = array(
				array(
					'name'         => 'name',
					'type'         => 'text',
					'label'        => 'Name',
					'placeholder'  => __('Enter your name', 'social-contact-form'),
					'required'     => true,
				),
				array(
					'name'         => 'email',
					'type'         => 'email',
					'label'        => 'Email',
					'placeholder'  => __('Enter your email', 'social-contact-form'),
					'required'     => true,
				),
				array(
					'name'        => 'phone',
					'type'        => 'tel',
					'label'       => 'Phone',
					'placeholder' => __('Enter your phone', 'social-contact-form'),
					'required'     => true,

				),
				array(
					'name'        => 'message',
					'type'        => 'textarea',
					'label'       => 'Message',
					'placeholder' => __('Enter your message', 'social-contact-form'),
					'required'     => true,
				),
			);

			return apply_filters('scf_fields', $fields);
		}

		// Font families
		public static function fonts()
		{ 


			$fonts = array(
				'sans-serif' => __('Default', 'social-contact-form'),
				'Arial' => __('Arial', 'social-contact-form'),
				'Arial Black' => __('Arial Black', 'social-contact-form'),
				'Comic Sans' => __('Comic Sans MS', 'social-contact-form'),
				'Courier New' => __('Courier New', 'social-contact-form'),
				'Georgia' => __('Georgia', 'social-contact-form'), 
				'Lucida Console' => __('Lucida Console', 'social-contact-form'),
				'Lucida Sans' => __('Lucida Sans', 'social-contact-form'), 
				'Tahoma' => __('Tahoma', 'social-contact-form'),
				'Times New Roman' => __('Times New Roman', 'social-contact-form'),
				'Trebuchet' => __('Trebuchet', 'social-contact-form'),
				'Verdana' => __('Verdana', 'social-contact-form'),
				'Ubuntu' => __('Ubuntu', 'social-contact-form'),
 
				'Roboto'        => __('Roboto', 'social-contact-form'),
				'Roboto Condensed' => __('Roboto Condensed', 'social-contact-form'),
				'Open Sans'     => __('Open Sans', 'social-contact-form'),
				'Lato'          => __('Lato', 'social-contact-form'),
				'Montserrat'    => __('Montserrat', 'social-contact-form'),
				'Raleway'       => __('Raleway', 'social-contact-form'),
				'PT Sans'       => __('PT Sans', 'social-contact-form'),
				'Roboto Slab'   => __('Roboto Slab', 'social-contact-form'),
				'Merriweather'  => __('Merriweather', 'social-contact-form'),
				'Playfair Display' => __('Playfair Display', 'social-contact-form'),
				'Source Sans Pro' => __('Source Sans Pro', 'social-contact-form'),
				'Noto Sans'     => __('Noto Sans', 'social-contact-form'),
				'Noto Serif'    => __('Noto Serif', 'social-contact-form'),
				'Roboto Mono'   => __('Roboto Mono', 'social-contact-form'),
				'Nunito'        => __('Nunito', 'social-contact-form'),
				'Poppins'        => __('Poppins', 'social-contact-form'),
				'Rubik'         => __('Rubik', 'social-contact-form'), 

			); 


			return apply_filters('scf_fonts', $fonts);
		}

		// country phone codes
		public static function countries()
		{
			$json = file_get_contents(SCF_DIR . '/public/json/countries.json');
			$countries = json_decode($json, true);


			// map only name, phone_code, emoji 
			$countries = array_map(function ($country) {
				return array(
					'name' => $country['name'] ?? '',
					'phone_code' => $country['phone_code'] ?? '',
					'emoji' => $country['emoji'] ?? '',
					'tags' => $country['tags'] ?? '',
				);
			}, $countries);


			return apply_filters('scf_countries', $countries);
		}

		public static function supported_tags()
		{
			$tags = [
				'break' => '',
			];

			return apply_filters('scf_preset_tags', $tags);
		}
		
		public static function premium_fonts()
		{
			$fonts = [
				'Ubuntu', 
				'Roboto',
				'Roboto Condensed',
				'Open Sans',
				'Lato',
				'Montserrat',
				'Raleway',
				'PT Sans',
				'Roboto Slab',
				'Merriweather',
				'Playfair Display',
				'Source Sans Pro',
				'Noto Sans',
				'Noto Serif',
				'Roboto Mono',
				'Nunito',
				'Poppins',
				'Rubik',				
			];

			return apply_filters('scf_premium_fonts', $fonts);
		}
	}

	new App();
endif;
