<?php

namespace WPPOOL\SCF;

if (!class_exists('\WPPOOL\SCF\Field')) :
	final class Field
	{
		public $field;
		public function __construct($field)
		{
			$this->field = $field;

			$this->init();
			$this->render_field();
		}

		# init 
		public function init()
		{
			$this->field['type'] = $this->field['type'] ?? 'text';
			$this->field['name'] = $this->field['name'] ?? '';
			$this->field['description'] = $this->field['description'] ?? '';
			$this->field['default'] = $this->field['default'] ?? '';
			$this->field['options'] = $this->field['options'] ?? array();
			$this->field['placeholder'] = $this->field['placeholder'] ?? '';
			$this->field['class'] = $this->field['class'] ?? '';
			$this->field['style'] = $this->field['style'] ?? '';
			$this->field['required'] = $this->field['required'] ?? false;
			$this->field['disabled'] = $this->field['disabled'] ?? false;
			$this->field['readonly'] = $this->field['readonly'] ?? false;
			$this->field['multiple'] = $this->field['multiple'] ?? false;
			$this->field['autocomplete'] = $this->field['autocomplete'] ?? false;
			$this->field['autofocus'] = $this->field['autofocus'] ?? false;
			$this->field['autocorrect'] = $this->field['autocorrect'] ?? false;
			$this->field['autocapitalize'] = $this->field['autocapitalize'] ?? false;
			$this->field['spellcheck'] = $this->field['spellcheck '] ?? false;
			$this->field['min'] = $this->field['min'] ?? '';
			$this->field['max'] = $this->field['max'] ?? '';
			$this->field['step'] = $this->field['step'] ?? '';
		}

		# init field
		public function render_field()
		{
			do_action('scf_before_field', $this->field);

			echo '<div class="scf-form-group">';

			switch ($this->field['type']) {
				case 'text':
					$this->render_text();
					break;
				case 'textarea':
					$this->render_textarea();
					break;
				case 'select':
					$this->render_select();
					break;
				case 'checkbox':
					$this->render_checkbox();
					break;
				case 'radio':
					$this->render_radio();
					break;
				case 'hidden':
					$this->render_hidden();
					break;
				default:
					$this->render_text();
					break;
			}

			echo '</div>';

			do_action('scf_after_field', $this->field);
		}

		# render text
		public function render_text()
		{
			$field = (object) $this->field;
			$required = $field->required == true ? 'required' : '';
			$pattern = $field->type == 'tel' ? 'pattern="\+?[0-9]{11,13}" ' : '';
			echo '<input type="' . esc_attr($field->type) . '" id="' . esc_attr($field->name) . '" name="' . esc_attr($field->name) . '" ' . esc_attr($required) . ' ' . $pattern. ' placeholder="' . esc_attr($field->placeholder) . '" />';
		}

		# render textarea
		public function render_textarea()
		{
			$field = (object) $this->field;
			$required = $field->required == true ? 'required' : '';
			echo '<textarea id="' . esc_attr($field->name) . '" name="' . esc_attr($field->name) . '" ' . esc_attr($required) . ' placeholder="' . esc_attr($field->placeholder) . '"></textarea>';
		}

		# render select
		public function render_select()
		{
			$field = (object) $this->field;
			$required = $field->required == true ? 'required' : '';
			$options = $field->options ?? array();
			$selected = $field->default ?? '';
			echo '<select id="' . esc_attr($field->name) . '" name="' . esc_attr($field->name) . '" ' . esc_attr($required) . '>';
			foreach ($options as $key => $value) {
				$selected_option = $selected == $key ? 'selected' : '';
				echo '<option value="' . esc_attr($key) . '" ' . esc_attr($selected_option) . '>' . esc_html($value) . '</option>';
			}
			echo '</select>';
		}

		# render checkbox
		public function render_checkbox()
		{
			$field = (object) $this->field;
			$required = $field->required == true ? 'required' : '';
			$checked = $field->default == true ? 'checked' : '';
			$label = $field->label ?? '';
			echo '<div class="scf-checkbox-wrap">';
			echo '<input type="checkbox" id="' . esc_attr($field->name) . '" name="' . esc_attr($field->name) . '" ' . esc_attr($required) . ' ' . esc_attr($checked) . ' />';
			echo '<label for="' . esc_attr($field->name) . '">' . esc_html($label) . '</label>';
			echo '</div>';
		}

		# render radio
		public function render_radio()
		{
			$field = (object) $this->field;
			$required = $field->required == true ? 'required' : '';
			$default =  $field->default ?? '';
			$options = $field->options ?? array();

			echo '<div class="scf-radio-wrap">';
			foreach ($options as $key => $value) {
				$checked = $default == $key ? 'checked' : '';
				echo '<div class="scf-radio-item">';
				echo '<input type="radio" id="' . esc_attr($field->name . '_' . $key) . '" name="' . esc_attr($field->name) . '" ' . esc_attr($required) . ' ' . esc_attr($checked) . ' value="' . esc_attr($key) . '" />';
				echo '<label for="' . esc_attr($field->name . '_' . $key) . '">' . esc_html($value) . '</label>';
				echo '</div>';
			}
			echo '</div>';
		}

		# render hidden
		public function render_hidden()
		{
			$field = (object) $this->field;
			$value = $field->value ?? '';
			echo '<input type="hidden" id="' . esc_attr($field->name) . '" name="' . esc_attr($field->name) . '" value="' . esc_attr($value) . '" />';
		}
	}
endif;
