<?php

namespace WPPOOL\SCF;

# Lead model for Social Contact Form

if (!class_exists('\WPPOOL\SCF\Lead')) :
	final class Lead
	{
		protected static $table_name = 'scf_leads';

		# Create table if it doesn't exist
		public static function create_table()
		{
			global $wpdb;
			$table_name = $wpdb->prefix . 'scf_leads';
			$charset_collate = $wpdb->get_charset_collate();

			$sql = "CREATE TABLE $table_name(
				id mediumint(11) NOT NULL AUTO_INCREMENT,
				field text NULL DEFAULT NULL,
				meta text NULL DEFAULT NULL,
				created_at datetime DEFAULT '0000-00-00 00:00:00' NOT NULL,
				deleted_at datetime DEFAULT NULL,
				note text DEFAULT NULL,
				PRIMARY KEY  (id)
			) $charset_collate;";

			require_once(ABSPATH . '/wp-admin/includes/upgrade.php');
			dbDelta($sql);
		}

		# Create lead 
		public static function create($field, $meta)
		{
			global $wpdb;
			$table_name = $wpdb->prefix . self::$table_name;

			$wpdb->insert(
				$table_name,
				array(
					'field' => json_encode($field),
					'meta' => json_encode($meta),
					'created_at' => current_time('mysql'),
				)
			);

			return $wpdb->insert_id;
		}

		# insert lead
		public static function insert($field, $meta)
		{
			return self::create($field, $meta);
		}

		# Get lead
		public static function get($id)
		{
			global $wpdb;
			$table_name = $wpdb->prefix . self::$table_name;

			$lead = $wpdb->get_row(
				$wpdb->prepare(
					"SELECT * FROM $table_name WHERE id = %d",
					$id
				)
			);

			if ($lead) {
				$lead->field = json_decode($lead->field);
				$lead->meta = json_decode($lead->meta);
			}

			return $lead;
		}

		# Get leads
		public static function get_all()
		{
			global $wpdb;
			$table_name = $wpdb->prefix . self::$table_name;

			$leads = $wpdb->get_results(
				"SELECT * FROM $table_name order by id desc"
			);

			if ($leads) {
				foreach ($leads as $lead) {
					$lead->field = json_decode($lead->field);
					$lead->meta = json_decode($lead->meta);
				}
			}

			return $leads;
		} 

		# Get leads count
		public static function get_count()
		{
			global $wpdb;
			$table_name = $wpdb->prefix . self::$table_name;

			return $wpdb->get_var(
				"SELECT COUNT(*) FROM $table_name"
			);
		}

		# Update lead
		public static function update($id, $field, $meta)
		{
			global $wpdb;
			$table_name = $wpdb->prefix . self::$table_name;

			$wpdb->update(
				$table_name,
				array(
					'field' => json_encode($field),
					'meta' => json_encode($meta),
					'created_at' => current_time('mysql'),
				),
				array(
					'id' => $id,
				)
			);
		}

		# Delete lead
		public static function delete($id)
		{
			global $wpdb;
			$table_name = $wpdb->prefix . self::$table_name;

			$wpdb->update(
				$table_name,
				array(
					'deleted_at' => current_time('mysql'),
				),
				array(
					'id' => $id,
				)
			);
		}

		# Delete multiple leads
		public static function delete_multiple($ids)
		{
			global $wpdb;
			$table_name = $wpdb->prefix . self::$table_name;
 
			$wpdb->query(
				$wpdb->prepare(
					"UPDATE $table_name SET deleted_at = %s WHERE id IN (%s)",				
					current_time('mysql'),
					implode(',', $ids)
				)
			);

			return $wpdb->rows_affected;
		}

		#Soft Delete all leads
		public static function delete_all()
		{
			global $wpdb;
			$table_name = $wpdb->prefix . self::$table_name;

			$wpdb->query( 
				$wpdb->prepare( "UPDATE %s SET deleted_at = '%s'", $table_name, current_time('mysql'))
			);

			return $wpdb->rows_affected;
		}

		# Hard delete all deleted leads
		public static function erase_all()
		{
			global $wpdb;
			$table_name = $wpdb->prefix . self::$table_name;

			$wpdb->query(
				$wpdb->prepare(
					"DELETE FROM %s WHERE deleted_at IS NOT NULL", $table_name
				)
			);

			$wpdb->query(
				"ALTER TABLE $table_name AUTO_INCREMENT = 1"
			);

			return $wpdb->rows_affected;
		}

		# Get lead field
		public static function get_field($id, $field)
		{
			$lead = self::get($id);

			if ($lead) {
				return $lead->field->$field;
			}

			return null;
		}

		# Get lead meta
		public static function get_meta($id, $meta)
		{
			$lead = self::get($id);

			if ($lead) {
				return $lead->meta->$meta;
			}

			return null;
		} 
	}

endif;
