<div x-ref="customize_form" class="flex items-center justify-between mb-4 border-l-4 border-indigo-600 pl-2" @scroll.window="handlerPreviewScreen">
    <div class="text-base font-semibold text-slate-600 block" @click.prevent="state.hide_customize_form = 0"><?php echo __('Customize Form', 'social-contact-form'); ?></div>
    <div class="flex items-center cursor-pointer text-slate-600 px-2 py-1 rounded-md hover:bg-slate-200 transition duration-150" @click.prevent="state.hide_customize_form = !state.hide_customize_form">
        <span class="dashicons" :class="[!state.hide_customize_form ? 'dashicons-arrow-up-alt2' : 'dashicons-arrow-down-alt2']"></span>
    </div>
</div>


<div x-show="!state.hide_customize_form" x-transition.opacity>
    <!-- form header text  -->
    <div class="mb-5">
        <label for="form_title" class="form-label"><?php echo __('Form Title', 'social-contact-form'); ?></label>
        <input id="form_title" placeholder="<?php echo __('Form Title i.e. Contact via WhatsApp', 'social-contact-form'); ?>" type="text" class="w-full scf-input" x-model="options.form.title">
    </div>

    <!-- form header description  -->
    <div class="mb-5">
        <label for="form_header" class="form-label"><?php echo __('Header Text', 'social-contact-form'); ?></label>
        <textarea id="form_header" placeholder="<?php echo __('Header Text i.e Please fill up the fields below', 'social-contact-form'); ?>" type="text" class="w-full scf-input p-2 px-3" x-model="options.form.header"></textarea>
    </div>

    <!-- form footer description  -->
    <div class="mb-5">
        <label for="form_footer" class="form-label"><?php echo __('Footer Text', 'social-contact-form'); ?></label>
        <textarea id="form_footer" placeholder="<?php echo __('Footer Text i.e. Powered by Social Contact Form', 'social-contact-form'); ?>" type="text" class="w-full scf-input p-2 px-3" x-model="options.form.footer"></textarea>
    </div>

    <!-- form submit button text  -->
    <div class="mb-5">
        <label for="form_submit" class="form-label"><?php echo __('Submit Button Text', 'social-contact-form'); ?></label>
        <input id="form_submit" placeholder="<?php echo __('Button Text i.e Send on WhatsApp', 'social-contact-form'); ?>" type="text" class="w-full scf-input" x-model="options.form.submit">
    </div>


    <!-- call to action text style  -->
    <div @click="upgradeModal" class="mb-5">
        <label class="form-label">
            <span :class="not_free"><?php echo __('Form Style', 'social-contact-form'); ?> </span>
            <ultimate-badge/></label>
        <div :class="not_free" class="w-full flex items-center gap-4">
            <div class="w-full flex items-center gap-4">
                <label for="form_color" class="cursor-pointer scf-input w-32 p-1.5 hover:shadow flex items-center gap-2">
                    <input type="color" id="form_color" class="invisible w-0 h-0" x-model="options.form.color">
                    <span class="w-4 h-4 rounded-full shadow" :style="{background: options.form.color}"></span> <?php echo __('Text Color', 'social-contact-form'); ?>
                </label>
                <label for="form_background" class="cursor-pointer scf-input w-32 p-1.5 hover:shadow flex items-center gap-2">
                    <input type="color" id="form_background" class="invisible w-0 h-0" x-model="options.form.background">
                    <span class="w-4 h-4 rounded-full shadow" :style="{background: options.form.background}"></span> <?php echo __('Background', 'social-contact-form'); ?>
                </label>
                 
            </div>
        </div>
    </div>


    <!-- form size  -->
    <div class="mb-5">
        <label class="form-label"><?php echo __('Form Size', 'social-contact-form'); ?></label>
        <div>
            <div class="w-auto inline-flex items-center rounded-md bg-slate-100  border border-slate-200 shadow-sm">
                <template x-for="size in ['small', 'medium', 'large', 'custom']">
                    <label class="px-3 py-1.5 rounded-sm capitalize border font-medium" x-text="size" :class="{
            'bg-white border-slate-100 text-indigo-600': size == options.form.size, 
            'border-transparent': size != options.form.size, 
            'opacity-40' : size == 'custom' && !isPro,
        }" @click.prevent="setFormSize(size)"> </label>
                </template>
            </div>
        </div>
    </div>


    <!-- custom form size  -->
    <div class="mb-5" x-show="options.form.size == 'custom'" x-transition @click.prevent="upgradeModal" :class="not_free">
        <label class="form-label"><?php echo __('Custom Size', 'social-contact-form'); ?></label>
        <div class="flex items-center gap-1">
            <span class="text-slate-400 text-sm"><?php echo __('Width', 'social-contact-form'); ?></span>
            <input class="scf-input w-20" x-model="options.form.size_custom" type="number" min="250" max="650" step="" placeholder="<?php echo __('Form Width', 'social-contact-form') ?>">
            <span class="text-slate-400 text-sm"><?php echo __('px', 'social-contact-form'); ?></span>
        </div>
    </div>

    <!-- select font family from dropdown                              -->
    <div class="mb-5">
        <label for="font_family" class="form-label"><?php echo __('Font Family', 'social-contact-form'); ?></label>
        <div class="w-full inline-flex items-center gap-2">
            <div class="w-1/2 inline-flex items-center justify-end gap-2">
                <?php $font_family = WPPOOL\SCF\App::fonts(); ?>
                <select class="w-full scf-input" x-model="options.form.font">                    
                    <?php
                    if ($font_family) {
                        $current = 0;
                        foreach ($font_family as $key => $value) {
                            $current++;
                            $disabled = $current > 14 && !is_scf_ultimate() ? 'disabled' : '';
                            $after = $current > 14 && !is_scf_ultimate() ? '<ultimate-badge/>' : '';
                            echo '<option value="' . esc_attr($key) . '" ' . esc_attr($disabled) . '>' . esc_html($value) . wp_kses_post($after) . '</option>';
                        }
                    }
                    ?>
                </select>
            </div>
        </div>
    </div>
</div>